Author: rhuijben
Date: Fri Nov 22 22:02:49 2013
New Revision: 1544693

URL: http://svn.apache.org/r1544693
Log:
* subversion/libsvn_wc/status.c
  (assemble_status,
   is_sendable_status): Show completely shadowed nodes that are moved to a
     different location as interesting status item.

Modified:
    subversion/trunk/subversion/libsvn_wc/status.c

Modified: subversion/trunk/subversion/libsvn_wc/status.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/status.c?rev=1544693&r1=1544692&r2=1544693&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/status.c (original)
+++ subversion/trunk/subversion/libsvn_wc/status.c Fri Nov 22 22:02:49 2013
@@ -576,19 +576,21 @@ assemble_status(svn_wc_status3_t **statu
       && prop_status != svn_wc_status_none)
     node_status = prop_status;
 
-  /* 5. Easy out:  unless we're fetching -every- entry, don't bother
-     to allocate a struct for an uninteresting entry. */
+  /* 5. Easy out:  unless we're fetching -every- node, don't bother
+     to allocate a struct for an uninteresting node.
 
+     This filter should match the filter in is_sendable_status() */
   if (! get_all)
     if (((node_status == svn_wc_status_none)
          || (node_status == svn_wc_status_normal))
 
         && (! switched_p)
-        && (! info->locked )
+        && (! info->locked)
         && (! info->lock)
         && (! repos_lock)
         && (! info->changelist)
-        && (! conflicted))
+        && (! conflicted)
+        && (! info->moved_to))
       {
         *status = NULL;
         return SVN_NO_ERROR;
@@ -1769,6 +1771,8 @@ make_file_baton(struct dir_baton *parent
  * Return a boolean answer to the question "Is @a status something that
  * should be reported?".  @a no_ignore and @a get_all are the same as
  * svn_wc_get_status_editor4().
+ *
+ * This implementation should match the filter in assemble_status()
  */
 static svn_boolean_t
 is_sendable_status(const svn_wc_status3_t *status,
@@ -1816,6 +1820,9 @@ is_sendable_status(const svn_wc_status3_
   if (status->changelist)
     return TRUE;
 
+  if (status->moved_to_abspath)
+    return TRUE;
+
   /* Otherwise, don't send it. */
   return FALSE;
 }


Reply via email to